import { Api } from './api';
import { Meta } from './core';
import { PathEventEmitter, PromiseProgress } from '@ztimson/utils';
export type Document<T> = Meta & T;
export type RawQuery = {
    operand: 'delete' | 'deleteOne' | 'find' | 'findOne' | 'insert' | 'replaceOne' | 'update' | 'updateOne';
    filter?: any;
    data?: any;
    options?: any;
    count?: boolean;
};
export type Schema = Meta & {
    /** Collection path/name */
    path: string;
    /** Description of data */
    description?: string;
    /** Last index number */
    autoIncrement?: number;
    /** Hide columns */
    hide?: string[];
    /** Lock collection from changes */
    lock?: boolean;
    /** Allow updates to create row if missing */
    upsert?: boolean;
    /** Defined fields */
    fields?: SchemaField[];
};
export type SchemaField = {
    /** Display label */
    label: string;
    /** Property key */
    property: string;
    /** Variable type */
    type: string;
    /** Display formating */
    format: string;
    /** Extra settings for formatting */
    formatArgs: any;
    /** Default value */
    default: any;
    /** Allow empty value */
    nullable: boolean;
};
/**
 * Recursive type for defining data schema
 */
export type SchemaNode = Schema & {
    name: string;
    children: SchemaNode[];
};
export declare class Data extends PathEventEmitter {
    private readonly api;
    constructor(api: Api | string);
    create<T>(collection: string, document: Document<T>): Promise<Document<T>>;
    delete(collection: string, id: number): Promise<void>;
    read<T extends Meta>(collection: string): Promise<T[]>;
    read<T extends Meta>(collection: string, id: number): Promise<T>;
    update<T>(collection: string, document: Document<T>, append?: boolean): Promise<Document<T>>;
    raw<T>(collection: string, query: RawQuery): Promise<Document<T>>;
    deleteSchema(path: string): PromiseProgress<any>;
    readSchema(tree?: false): Promise<string[]>;
    readSchema(tree?: boolean): Promise<SchemaNode[]>;
    readSchema(path?: string): Promise<Schema>;
    updateSchema(schema: Partial<Schema> & {
        path: string;
    }): PromiseProgress<Schema>;
}
//# sourceMappingURL=data.d.ts.map